@@ -1,7 +1,7 @@
-# last modified 29 November 03 by J. Fox
+# last modified 22 December 03 by J. Fox
 
 .onAttach <- function(...){
-    cat("\nRcmdr Version 0.9-2\n")
+    cat("\nRcmdr Version 0.9-3\n")
     Commander()
     }
 
@@ -14,13 +14,14 @@
     ctest <- require(ctest)
     tcltk <- require(tcltk)
     abind <- require(abind)
+    lmtest <- require(lmtest)
     effects <- require(effects)
     car <- require(car)
-    absent <- !c(lattice, foreign, mva, ctest, tcltk, abind, effects, car)
+    absent <- !c(lattice, foreign, mva, ctest, tcltk, abind, lmtest, effects, car)
     if (any(absent)) {
         cat("\nThe following packages required by Rcmdr are missing:\n")
-        cat(paste(c("lattice", "foreign", "mva", "ctest", "tcltk", "abind", "effects", "car")[absent], 
-            collapse=", "))
+        cat(paste(c("lattice", "foreign", "mva", "ctest", "tcltk", "abind", "lmtest", 
+            "effects", "car")[absent], collapse=", "))
         cat("\n")
         }
     }
